@@ -1,7 +1,7 @@
 package Google::Adwords;
 use strict; use warnings;
 
-use version; our $VERSION = qv('0.4');
+use version; our $VERSION = qv('0.5');
 
 1;
 
@@ -14,7 +14,7 @@ Google::Adwords - an interface which abstracts the Google Adwords SOAP API
  
 =head1 VERSION
  
-This documentation refers to Google::Adwords version 0.4
+This documentation refers to Google::Adwords version 0.5
  
  
 =head1 SYNOPSIS
@@ -81,6 +81,8 @@ Each API Service belongs to a particular module.
 
 * CreativeService       - L<Google::Adwords::CreativeService>
 
+* ReportService         - L<Google::Adwords::ReportService>
+
 Some services like the CampaignService need to deal with complex data 
 types which are available as objects.
 
@@ -106,6 +108,8 @@ types which are available as objects.
 
 * Image                 - L<Google::Adwords::Image>
 
+* ReportJob             - L<Google::Adwords::ReportJob>
+
 Please read the documentation for the above modules.
  
 =head1 DEPENDENCIES
